@@ -27,11 +27,11 @@ from django.db import models
 from cms.test_utils.project.extensionapp.models import MyPageExtension
 
 from Iuppiter.Util import extractZip
-from Zephyrus.statistics.models import URL
+from Zephyrus.stats.models import URL
 
 import sys
 import argparse
-from Zephyrus.statistics.templatetags.StatisticsTags import viewCount
+from Zephyrus.stats.templatetags.StatisticsTags import viewCount
 
 class Command(BaseCommand):
     help = 'add the arguments(path, language, namespace, imgClass)'
