@@ -15,7 +15,7 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='DatePluginConfig',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_datepluginconfig', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_datepluginconfig', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('renderTemplate', models.CharField(default=b'blog_extension/Date.html', max_length=150, verbose_name='Render template', choices=[(b'blog_extension/Date.html', 'Default')])),
             ],
             options={
