@@ -32,20 +32,26 @@ def configure():
     # Load fixtures if needed.
     pages = Page.objects.exists()
     _SERVER_MODE = settings.SERVER_MODE
-    
+
     initialData = hasattr(settings, 'ZEPHYRUS_CMS_INITIAL_DATA')
-    
+    initialDataOptions = hasattr(settings, 'ZEPHYRUS_CMS_INITIAL_DATA_OPTIONS')
+
     if not initialData:
         return
     initialData = settings.ZEPHYRUS_CMS_INITIAL_DATA
+    if initialDataOptions:
+        initialDataOptions = settings.ZEPHYRUS_CMS_INITIAL_DATA_OPTIONS
 
     logger.info('Check if need to load data...')
-    
+
     if _SERVER_MODE == settings.DEVELOPMENT:
         if not pages:
             logger.info("Loading %s" % initialData)
             try:
-                call_command('cms_loaddata', initialData)
+                if initialDataOptions:
+                    call_command('cms_loaddata', initialData, initialDataOptions)
+                else:
+                    call_command('cms_loaddata', initialData)
                 logger.info('Load cms data success.')
             except Exception as e:
                 logger.info("cms_loaddata error: %s" % str(e))
@@ -54,7 +60,7 @@ def configure():
     else:
         if not pages:
             logger.info('Open original data...')
-                
+
             with open(initialData, "r") as jsonFile:
                 data = json.load(jsonFile)
 
@@ -63,7 +69,7 @@ def configure():
                 if 'site' in ele['fields']:
                     if ele['fields']['site']:
                         ele['fields']['site'] = _SERVER_MODE
-            
+
             logger.info('Dump edited cms data...')
             updatedCmsDataPath = os.path.join(
                 'initial_data_%s.json' % (_SERVER_MODE, )
@@ -71,7 +77,7 @@ def configure():
 
             with open(updatedCmsDataPath, 'w') as outfile:
                 json.dump(data, outfile)
-            
+
             logger.info("Loading initial cms data...")
             try:
                 call_command(
@@ -81,4 +87,4 @@ def configure():
             except Exception as e:
                 logger.info("cms_loaddata error: %s" % str(e))
         else:
-            logger.info('No need to load cms data')
\ No newline at end of file
+            logger.info('No need to load cms data')
