@@ -15,7 +15,7 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='RecentResponsePlugin',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='comment_recentresponseplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='comment_recentresponseplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('limit', models.PositiveIntegerField(default=6)),
                 ('renderTemplate', models.CharField(default=b'comment/RecentResponse.html', max_length=150, verbose_name='Comment Template', blank=True, choices=[(b'comment/RecentResponse.html', 'Default')])),
             ],
