@@ -20,5 +20,5 @@ from django.apps import AppConfig
 from django.utils.translation import ugettext_lazy as _
 
 class FacebookConfig(AppConfig):
-    name = 'Facebook.comment'
+    name = 'Zephyrus.facebook'
     verbose_name = _("Facebook")
\ No newline at end of file
